@@ -2,16 +2,20 @@ from __future__ import annotations
 
 import importlib
 import pkgutil
+import sys
 import warnings
-from typing import Iterable, Optional
+from typing import Iterable
 
-import importlib_metadata as metadata
+if sys.version_info >= (3, 10):
+    from importlib import metadata
+else:
+    import importlib_metadata as metadata
 
 from commitizen.cz.base import BaseCommitizen
 
 
 def discover_plugins(
-    path: Optional[Iterable[str]] = None,
+    path: Iterable[str] | None = None,
 ) -> dict[str, type[BaseCommitizen]]:
     """Discover commitizen plugins on the path
 
